| df_split_col | R Documentation |
Given a data frame x, a column name and a naming
scheme, the function splits every element in x[[split.col]],
using the naming scheme. Next, either a data frame with column names
indicating the split parts for each unique value in x[[split.col]]
is returned, or, if append=TRUE, this data frame is left-joined
with x by split.col.
df_split_col(x, split.col, scheme, delim, append = TRUE)
x |
[ |
split.col |
[ |
scheme |
[ |
delim |
[ |
append |
[ |
Modified data frame.
Other data frame helpers:
df_add_category(),
df_add_constant_columns(),
df_explode(),
df_rows_to_list()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.